==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_so.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_so extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "DBB" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "S" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Dirhamka Isutaga Imaaraatka Carabta" },
            { "afn", "Afgan Afgani" },
            { "all", "Lekta Albaniya" },
            { "amd", "Daraamka Armeniya" },
            { "ang", "Galdarka Nadarlaan Antiliyaan" },
            { "aoa", "Kawansada Angola" },
            { "ars", "Beesada Arjentiin" },
            { "aud", "Doolarka Astaraaliya" },
            { "awg", "Foloorinta Aruban" },
            { "azn", "Manaata Asarbeyjan" },
            { "bam", "Konfatibal Maakta Bosnia-Hersogofina" },
            { "bbd", "Doolarka Barbaadiyaan" },
            { "bdt", "Taka Bangledesh" },
            { "bgn", "Lefta Bulgariya" },
            { "bhd", "Dinaarka Baxreyn" },
            { "bif", "Faranka Burundi" },
            { "bmd", "Doolarka Barmuuda" },
            { "bnd", "Doolarka Buruney" },
            { "bob", "Bolifiyanada Bolifiya" },
            { "brl", "Realka Barasil" },
            { "bsd", "Doolarka Bahamaas" },
            { "btn", "Nugultaramta Butan" },
            { "bwp", "Buulada Botswana" },
            { "byn", "Rubalka Belarus" },
            { "bzd", "Doolarka Beelisa" },
            { "cad", "Doolarka Kanada" },
            { "cdf", "Faranka Kongo" },
            { "chf", "Faranka Iswiska" },
            { "clp", "Beesada Jili" },
            { "cnh", "Yuwanta Shiinaha (Ofshoor)" },
            { "cny", "Yuwanta Shiinaha" },
            { "cop", "Beesada Kolombiya" },
            { "crc", "Kolonka Kosta Riika" },
            { "cuc", "Beesada Konfatibal ee Kuuba" },
            { "cup", "Beesada Kuuba" },
            { "cve", "Eskudo Keyb Farde" },
            { "czk", "Korunada Jeek" },
            { "djf", "Faran Jabuuti" },
            { "dkk", "Koronka Danishka" },
            { "dop", "Beesada Dominiika" },
            { "dzd", "Dinaarka Aljeriya" },
            { "egp", "Bowndka Masar" },
            { "ern", "Nakfada Eritriya" },
            { "etb", "Birta Itoobbiya" },
            { "eur", "Yuuroo" },
            { "fjd", "Doolarka Fiji" },
            { "fkp", "Bowndka Faalklaan Aylaanis" },
            { "gbp", "Bowndka Biritishka" },
            { "gel", "Laariga Joorjiya" },
            { "ghs", "Sedida Gana" },
            { "gip", "Bowndka Gibraltar" },
            { "gmd", "Dalasida Gambiya" },
            { "gnf", "Faranka Gini" },
            { "gtq", "Kuwestalka Guwatemala" },
            { "gyd", "Doolarka Guyanes" },
            { "hkd", "Doolarka Hoon Koon" },
            { "hnl", "Lembirada Honduras" },
            { "hrk", "Kunada Korooshiya" },
            { "htg", "Goordada Hiyati" },
            { "huf", "Forintiska Hangari" },
            { "idr", "Rubiah Indonesiya" },
            { "ils", "Niyuu Shekelka Israaiil" },
            { "inr", "Rubiga Hindiya" },
            { "iqd", "Dinaarka Ciraaq" },
            { "irr", "Riyaalka Iran" },
            { "isk", "Koronada Eysland" },
            { "jmd", "Doolarka Jamayka" },
            { "jod", "Dinaarka Urdun" },
            { "jpy", "Yenta Jabaan" },
            { "kes", "Shilingka Kenya" },
            { "kgs", "Somta Kiyrgiystan" },
            { "khr", "Riyf kambodiya" },
            { "kmf", "Faranka Komoros" },
            { "kpw", "Wonka Waqooyiga Kuuriya" },
            { "krw", "Wonka Koonfur Kuuriya" },
            { "kwd", "Dinaarka Kuweyt" },
            { "kyd", "Doolarka Kayman Aylaanis" },
            { "kzt", "Tengeda Kasakhstan" },
            { "lak", "Kib Laoti" },
            { "lbp", "Bowndka Lubnaan" },
            { "lkr", "Rubiga Siri lanka" },
            { "lrd", "Doolarka Liberiya" },
            { "lyd", "Dinaarka Libya" },
            { "mad", "Dirhamka Moroko" },
            { "mdl", "Leeyuuda Moldofa" },
            { "mga", "Arayrida Madagaskar" },
            { "mkd", "Denaarka Masedoniya" },
            { "mmk", "Kayatda Mayanmaar" },
            { "mnt", "Tugrikta Mongoliya" },
            { "mop", "Bataka Makana" },
            { "mro", "Oogiya Mawritaniya (1973\u20132017)" },
            { "mru", "Oogiyada Mawritaaniya" },
            { "mur", "Rubiga Mowrishiya" },
            { "mvr", "Rufiyada Maldifiya" },
            { "mwk", "Kawajada Malawi" },
            { "mxn", "Beesada Meksiko" },
            { "myr", "Ringitda Malayshiya" },
            { "mzn", "Metikalka Mosambik" },
            { "nad", "Doolarka Namibiya" },
            { "ngn", "Nairada Neyjeeriya" },
            { "nio", "Kordobada Nikargow" },
            { "nok", "Koronka Norway" },
            { "npr", "Rubiga Nebal" },
            { "nzd", "Doolarka Niyuu Siyalaan" },
            { "omr", "Riyaalka Cumaan" },
            { "pab", "Balbow Banama" },
            { "pen", "Solsha Beeru" },
            { "pgk", "Kinada Babua Niyuu Gini" },
            { "php", "Biso Filibin" },
            { "pkr", "Rubiga Bakistan" },
            { "pln", "Solotida Bolaan" },
            { "pyg", "Guranida Baraguway" },
            { "qar", "Riyaalka Qatar" },
            { "ron", "Liyuuda Romaniya" },
            { "rsd", "Dinaarka Serbiya" },
            { "rub", "Rubalka Ruushka" },
            { "rwf", "Faranka Ruwanda" },
            { "sar", "Riyaalka Sacuudiga" },
            { "sbd", "Doolarka Solomon Aylaanis" },
            { "scr", "Rubiga Siisalis" },
            { "sdg", "Bowndka Suudaan" },
            { "sek", "Koronka Isweden" },
            { "sgd", "Doolarka Singabuur" },
            { "shp", "Bowndka St Helen" },
            { "sll", "Leonka Sira Leon" },
            { "sos", "Shilingka Soomaaliya" },
            { "srd", "Doolarka Surinamees" },
            { "ssp", "Bowndka Koonfurta Suudaan" },
            { "stn", "Dobra Sao Tome & Birinsibi" },
            { "syp", "Bowndka Suuriya" },
            { "szl", "Lilangeenida iswaasi" },
            { "thb", "Baatka Taylaan" },
            { "tjs", "Somoonida Tajikistan" },
            { "tmt", "Manaata Turkmenistan" },
            { "tnd", "Dinaarka Tunisiya" },
            { "top", "Ba\u2019angada Tonga" },
            { "try", "Liirada Turkiga" },
            { "ttd", "Doolarka Tirinidad iyo Tobago" },
            { "twd", "Doolarka Taywaanta Cusub" },
            { "tzs", "Shilingka Tansaaniya" },
            { "uah", "Hirfiniyada Yukreeyn" },
            { "ugx", "Shilingka Yugandha" },
            { "usd", "Doolarka Mareeykanka" },
            { "uyu", "Beesada Urugway" },
            { "uzs", "Somta Usbekistan" },
            { "vef", "Bolifar Fenesuala (2008\u20132018)" },
            { "ves", "Bolifarada Fenesuwela" },
            { "vnd", "Dongta Fitnaam" },
            { "vuv", "Fatu Fanuatu" },
            { "wst", "Tala Samao" },
            { "xaf", "Faranka CFA ee Bartamaha Afrika" },
            { "xcd", "Doolarka Iist Kaaribyan" },
            { "xof", "Faranka CFA Galbeedka Afrika" },
            { "xpf", "Faranka CFP" },
            { "xxx", "Lacag aan la aqoon" },
            { "yer", "Riyaalka Yemen" },
            { "zar", "Randka Koonfur Afrika" },
            { "zmw", "Kawajada Sambiya" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_so.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_so extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BBD", "DBB" },
            { "MRO", "MRO" },
            { "SOS", "S" },
            { "VEF", "VEF" },
            { "aed", "Dirhamka Isutaga Imaaraatka Carabta" },
            { "afn", "Afgan Afgani" },
            { "all", "Lekta Albaniya" },
            { "amd", "Daraamka Armeniya" },
            { "ang", "Galdarka Nadarlaan Antiliyaan" },
            { "aoa", "Kawansada Angola" },
            { "ara", "Argentine Austral" },
            { "arl", "Beesada Ley ee Arjentiin (1970\u20131983)" },
            { "arm", "Beesada Ley ee Arjentiin (1881\u20131970)" },
            { "arp", "Beesada Ley ee Arjentiin (1883\u20131985)" },
            { "ars", "Beesada Arjentiin" },
            { "aud", "Doolarka Astaraaliya" },
            { "awg", "Foloorinta Aruban" },
            { "azn", "Manaata Asarbeyjan" },
            { "bad", "Diinaarka BBosnia-Hersogofina 1.00 konfatibal maakta Bosnia-Hersogofina 1 konfatibal maaka Bosnia-Hersogofina (1992\u20131994)" },
            { "bam", "Konfatibal Maakta Bosnia-Hersogofina" },
            { "bbd", "Doolarka Barbaadiyaan" },
            { "bdt", "Taka Bangledesh" },
            { "bgn", "Lefta Bulgariya" },
            { "bhd", "Dinaarka Baxreyn" },
            { "bif", "Faranka Burundi" },
            { "bmd", "Doolarka Barmuuda" },
            { "bnd", "Doolarka Buruney" },
            { "bob", "Bolifiyanada Bolifiya" },
            { "bol", "Bolifiyaabka Bolifiyaano(1863\u20131963)" },
            { "brl", "Realka Barasil" },
            { "bsd", "Doolarka Bahamaas" },
            { "btn", "Nugultaramta Butan" },
            { "bwp", "Buulada Botswana" },
            { "byn", "Rubalka Belarus" },
            { "bzd", "Doolarka Beelisa" },
            { "cad", "Doolarka Kanada" },
            { "cdf", "Faranka Kongo" },
            { "chf", "Faranka Iswiska" },
            { "clp", "Beesada Jili" },
            { "cnh", "Yuwanta Shiinaha (Ofshoor)" },
            { "cny", "Yuwanta Shiinaha" },
            { "cop", "Beesada Kolombiya" },
            { "crc", "Kolonka Kosta Riika" },
            { "cuc", "Beesada Konfatibal ee Kuuba" },
            { "cup", "Beesada Kuuba" },
            { "cve", "Eskudo Keyb Farde" },
            { "czk", "Korunada Jeek" },
            { "djf", "Faran Jabuuti" },
            { "dkk", "Koronka Danishka" },
            { "dop", "Beesada Dominiika" },
            { "dzd", "Dinaarka Aljeriya" },
            { "eek", "Kroonka Estooniya" },
            { "egp", "Bowndka Masar" },
            { "ern", "Nakfada Eritriya" },
            { "etb", "Birta Itoobbiya" },
            { "eur", "Yuuroo" },
            { "fim", "Markkada Fiinishka ah" },
            { "fjd", "Doolarka Fiji" },
            { "fkp", "Bowndka Faalklaan Aylaanis" },
            { "gbp", "Bowndka Biritishka" },
            { "gel", "Laariga Joorjiya" },
            { "ghs", "Sedida Gana" },
            { "gip", "Bowndka Gibraltar" },
            { "gmd", "Dalasida Gambiya" },
            { "gnf", "Faranka Gini" },
            { "gtq", "Kuwestalka Guwatemala" },
            { "gyd", "Doolarka Guyanes" },
            { "hkd", "Doolarka Hoon Koon" },
            { "hnl", "Lembirada Honduras" },
            { "hrk", "Kunada Korooshiya" },
            { "htg", "Goordada Hiyati" },
            { "huf", "Forintiska Hangari" },
            { "idr", "Rubiah Indonesiya" },
            { "iep", "baawnka Ayrishka" },
            { "ils", "Niyuu Shekelka Israaiil" },
            { "inr", "Rubiga Hindiya" },
            { "iqd", "Dinaarka Ciraaq" },
            { "irr", "Riyaalka Iran" },
            { "isk", "Koronada Eysland" },
            { "jmd", "Doolarka Jamayka" },
            { "jod", "Dinaarka Urdun" },
            { "jpy", "Yenta Jabaan" },
            { "kes", "Shilingka Kenya" },
            { "kgs", "Somta Kiyrgiystan" },
            { "khr", "Riyf kambodiya" },
            { "kmf", "Faranka Komoros" },
            { "kpw", "Wonka Waqooyiga Kuuriya" },
            { "krw", "Wonka Koonfur Kuuriya" },
            { "kwd", "Dinaarka Kuweyt" },
            { "kyd", "Doolarka Kayman Aylaanis" },
            { "kzt", "Tengeda Kasakhstan" },
            { "lak", "Kib Laoti" },
            { "lbp", "Bowndka Lubnaan" },
            { "lkr", "Rubiga Siri lanka" },
            { "lrd", "Doolarka Liberiya" },
            { "lvr", "Rubalka Latfiya" },
            { "lyd", "Dinaarka Libya" },
            { "mad", "Dirhamka Moroko" },
            { "mdl", "Leeyuuda Moldofa" },
            { "mga", "Arayrida Madagaskar" },
            { "mkd", "Denaarka Masedoniya" },
            { "mmk", "Kayatda Mayanmaar" },
            { "mnt", "Tugrikta Mongoliya" },
            { "mop", "Bataka Makana" },
            { "mro", "Oogiya Mawritaniya (1973\u20132017)" },
            { "mru", "Oogiyada Mawritaaniya" },
            { "mur", "Rubiga Mowrishiya" },
            { "mvr", "Rufiyada Maldifiya" },
            { "mwk", "Kawajada Malawi" },
            { "mxn", "Beesada Meksiko" },
            { "myr", "Ringitda Malayshiya" },
            { "mzn", "Metikalka Mosambik" },
            { "nad", "Doolarka Namibiya" },
            { "ngn", "Nairada Neyjeeriya" },
            { "nio", "Kordobada Nikargow" },
            { "nok", "Koronka Norway" },
            { "npr", "Rubiga Nebal" },
            { "nzd", "Doolarka Niyuu Siyalaan" },
            { "omr", "Riyaalka Cumaan" },
            { "pab", "Balbow Banama" },
            { "pen", "Solsha Beeru" },
            { "pgk", "Kinada Babua Niyuu Gini" },
            { "php", "Biso Filibin" },
            { "pkr", "Rubiga Bakistan" },
            { "pln", "Solotida Bolaan" },
            { "pyg", "Guranida Baraguway" },
            { "qar", "Riyaalka Qatar" },
            { "ron", "Liyuuda Romaniya" },
            { "rsd", "Dinaarka Serbiya" },
            { "rub", "Rubalka Ruushka" },
            { "rwf", "Faranka Ruwanda" },
            { "sar", "Riyaalka Sacuudiga" },
            { "sbd", "Doolarka Solomon Aylaanis" },
            { "scr", "Rubiga Siisalis" },
            { "sdg", "Bowndka Suudaan" },
            { "sek", "Koronka Isweden" },
            { "sgd", "Doolarka Singabuur" },
            { "shp", "Bowndka St Helen" },
            { "sll", "Leonka Sira Leon" },
            { "sos", "Shilingka Soomaaliya" },
            { "srd", "Doolarka Surinamees" },
            { "ssp", "Bowndka Koonfurta Suudaan" },
            { "stn", "Dobra Sao Tome & Birinsibi" },
            { "syp", "Bowndka Suuriya" },
            { "szl", "Lilangeenida iswaasi" },
            { "thb", "Baatka Taylaan" },
            { "tjs", "Somoonida Tajikistan" },
            { "tmt", "Manaata Turkmenistan" },
            { "tnd", "Dinaarka Tunisiya" },
            { "top", "Ba\u2019angada Tonga" },
            { "try", "Liirada Turkiga" },
            { "ttd", "Doolarka Tirinidad iyo Tobago" },
            { "twd", "Doolarka Taywaanta Cusub" },
            { "tzs", "Shilingka Tansaaniya" },
            { "uah", "Hirfiniyada Yukreeyn" },
            { "ugx", "Shilingka Yugandha" },
            { "usd", "Doolarka Mareeykanka" },
            { "uyu", "Beesada Urugway" },
            { "uzs", "Somta Usbekistan" },
            { "vef", "Bolifar Fenesuala (2008\u20132018)" },
            { "ves", "Bolifarada Fenesuwela" },
            { "vnd", "Dongta Fitnaam" },
            { "vuv", "Fatu Fanuatu" },
            { "wst", "Tala Samao" },
            { "xaf", "Faranka CFA ee Bartamaha Afrika" },
            { "xcd", "Doolarka Iist Kaaribyan" },
            { "xof", "Faranka CFA Galbeedka Afrika" },
            { "xpf", "Faranka CFP" },
            { "xxx", "Lacag aan la aqoon" },
            { "yer", "Riyaalka Yemen" },
            { "zar", "Randka Koonfur Afrika" },
            { "zmw", "Kawajada Sambiya" },
        };
        return data;
    }
}
